@@ -1,7 +1,7 @@
 package Software::Catalog::SW::firefox;
 
-our $DATE = '2018-09-20'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2018-10-04'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -9,10 +9,16 @@ use warnings;
 
 use Role::Tiny::With;
 with 'Software::Catalog::Role::Software';
-with 'Software::Catalog::Role::VersionScheme::SemVer';
 
 use Software::Catalog::Util qw(extract_from_url);
 
+sub meta {
+    return {
+        homepage_url => "https://mozilla.org/firefox",
+        versioning_scheme => "Dotted",
+    };
+}
+
 sub get_latest_version {
     my ($self, %args) = @_;
 
@@ -70,7 +76,7 @@ Software::Catalog::SW::firefox - Firefox
 
 =head1 VERSION
 
-This document describes version 0.002 of Software::Catalog::SW::firefox (from Perl distribution Software-Catalog-SW-firefox), released on 2018-09-20.
+This document describes version 0.003 of Software::Catalog::SW::firefox (from Perl distribution Software-Catalog-SW-firefox), released on 2018-10-04.
 
 =for Pod::Coverage ^(.+)$
 
